==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1StorageOSPersistentVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1StorageOSPersistentVolumeSourceFluent<A extends V1StorageOSPersistentVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectReference getSecretRef();
    public V1ObjectReference buildSecretRef();
    public A withSecretRef(V1ObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1ObjectReference item);
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1ObjectReference item);
    public String getVolumeName();
    public A withVolumeName(String volumeName);
    public Boolean hasVolumeName();
    public String getVolumeNamespace();
    public A withVolumeNamespace(String volumeNamespace);
    public Boolean hasVolumeNamespace();

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectReferenceFluent<V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1StorageOSPersistentVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1StorageOSPersistentVolumeSourceFluent<A extends V1StorageOSPersistentVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectReference getSecretRef();
    public V1ObjectReference buildSecretRef();
    public A withSecretRef(V1ObjectReference secretRef);
    public Boolean hasSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1ObjectReference item);
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1ObjectReference item);
    public String getVolumeName();
    public A withVolumeName(String volumeName);
    public Boolean hasVolumeName();
    public A withNewVolumeName(String arg1);
    public A withNewVolumeName(StringBuilder arg1);
    public A withNewVolumeName(StringBuffer arg1);
    public String getVolumeNamespace();
    public A withVolumeNamespace(String volumeNamespace);
    public Boolean hasVolumeNamespace();
    public A withNewVolumeNamespace(String arg1);
    public A withNewVolumeNamespace(StringBuilder arg1);
    public A withNewVolumeNamespace(StringBuffer arg1);

    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectReferenceFluent<V1StorageOSPersistentVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
